@@ -15,10 +15,10 @@ memes: List[Meme] = [
     Meme("slap", slap, ("一巴掌",)),
     Meme("imprison", imprison, ("坐牢",)),
     Meme("scroll", scroll, ("滚屏",)),
-    Meme("high_EQ", high_EQ, ("低情商xx高情商xx",), r"低情商(?P<left>.*?)\s+高情商(?P<right>.*)"),
+    Meme("high_EQ", high_EQ, ("低情商xx 高情商xx",), r"低情商(?P<left>.*?)\s+高情商(?P<right>.*)"),
     Meme("wujing", wujing, ("吴京xx中国xx",), r"吴京[\s:：]*(?P<left>.*?)中国(?P<right>.*)"),
     Meme("slogan", slogan, ("口号",)),
-    Meme("wakeup", wakeup, ("xx起来了",), r"(?P<text>.*?)起来了"),
+    Meme("wakeup", wakeup, ("xx 起来了",), r"(?P<text>.*?)\s+起来了"),
     Meme("raisesign", raisesign, ("举牌",)),
     Meme("psyduck", psyduck, ("可达鸭",)),
     Meme("scratchoff", scratchoff, ("刮刮乐",)),
@@ -33,6 +33,7 @@ memes: List[Meme] = [
     Meme("google", google, ("google",)),
     Meme("5000choyen", fivethousand_choyen, ("5000兆",)),
     Meme("douyin", douyin, ("douyin",)),
+    Meme("not_call_me", not_call_me, ("不喊我",), ),
     GifMeme("wangjingze", wangjingze, ("王境泽",)),
     GifMeme("weisuoyuwei", weisuoyuwei, ("为所欲为",)),
     GifMeme("chanshenzi", chanshenzi, ("馋身子",)),
