@@ -133,7 +133,7 @@ def murmur(text: str = Arg()):
             (10, 255, 430, 300),
             text,
             max_fontsize=40,
-            min_fontsize=20,
+            min_fontsize=15,
         )
     except ValueError:
         return OVER_LENGTH_MSG
@@ -148,7 +148,7 @@ def shutup(text: str = Arg()):
             text,
             allow_wrap=True,
             max_fontsize=40,
-            min_fontsize=20,
+            min_fontsize=15,
         )
     except ValueError:
         return OVER_LENGTH_MSG
@@ -163,7 +163,7 @@ def slap(text: str = Arg()):
             text,
             allow_wrap=True,
             max_fontsize=110,
-            min_fontsize=65,
+            min_fontsize=50,
         )
     except ValueError:
         return OVER_LENGTH_MSG
@@ -284,7 +284,7 @@ def slogan(texts: List[str] = Args(6, prompt=True)):
     frame = load_image("slogan/0.jpg")
 
     def draw(pos: Tuple[float, float, float, float], text: str):
-        frame.draw_text(pos, text, max_fontsize=40, min_fontsize=20, allow_wrap=True)
+        frame.draw_text(pos, text, max_fontsize=40, min_fontsize=15, allow_wrap=True)
 
     try:
         draw((10, 0, 294, 50), texts[0])
@@ -318,7 +318,7 @@ def raisesign(text: str = Arg()):
             (10, 10, 350, 250),
             text,
             max_fontsize=80,
-            min_fontsize=40,
+            min_fontsize=30,
             allow_wrap=True,
             lines_align="center",
             spacing=10,
@@ -395,7 +395,7 @@ def scratchoff(text: str = Arg()):
             text,
             allow_wrap=True,
             max_fontsize=80,
-            min_fontsize=40,
+            min_fontsize=30,
             fill="white",
             lines_align="center",
         )
@@ -496,7 +496,7 @@ def bronya_holdsign(text: str = Arg()):
             fill=(111, 95, 95),
             allow_wrap=True,
             max_fontsize=60,
-            min_fontsize=30,
+            min_fontsize=25,
         )
     except ValueError:
         return OVER_LENGTH_MSG
@@ -599,12 +599,19 @@ def fivethousand_choyen(texts: List[str] = Args(2, prompt=True)):
             Resampling.BILINEAR,
         )
 
+    def shift(t2m: Text2Image) -> Tuple[int, int]:
+        return (
+            pos_x
+            - t2m.lines[0].chars[0].stroke_width
+            - max(char.stroke_width for char in t2m.lines[0].chars),
+            pos_y - t2m.lines[0].ascent,
+        )
+
     def add_color_text(stroke_width: int, fill: str, pos: Tuple[int, int]):
         t2m = Text2Image.from_text(
             text, fontsize, fontname=fontname, stroke_width=stroke_width, fill=fill
         )
-        dx = pos_x - stroke_width * 2
-        dy = pos_y - t2m.lines[0].ascent
+        dx, dy = shift(t2m)
         imgs.append((transform(t2m.to_image()), (dx + pos[0], dy + pos[1])))
 
     def add_gradient_text(
@@ -617,8 +624,7 @@ def fivethousand_choyen(texts: List[str] = Args(2, prompt=True)):
             text, fontsize, fontname=fontname, stroke_width=stroke_width, fill="white"
         )
         mask = transform(t2m.to_image()).convert("L")
-        dx = pos_x - stroke_width * 2
-        dy = pos_y - t2m.lines[0].ascent
+        dx, dy = shift(t2m)
         gradient = LinearGradient(
             (dir[0] - dx, dir[1] - dy, dir[2] - dx, dir[3] - dy),
             [ColorStop(*color_stop) for color_stop in color_stops],
@@ -811,3 +817,18 @@ def douyin(text: str = Arg()):
         frames.append(bg.image)
 
     return save_gif(frames, 0.2)
+
+
+def not_call_me(text: str = Arg()):
+    frame = load_image("not_call_me/0.png")
+    try:
+        frame.draw_text(
+            (228, 11, 340, 164),
+            text,
+            allow_wrap=True,
+            max_fontsize=80,
+            min_fontsize=20,
+        )
+    except ValueError:
+        return OVER_LENGTH_MSG
+    return frame.save_png()
